@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2016-2022, Intel Corporation
+ * Copyright (c) 2016-2023, Intel Corporation
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -506,7 +507,8 @@ static inline int block_to_user(struct pt_block *ublock, size_t size,
 
 	/* Zero out any unknown bytes. */
 	if (sizeof(*block) < size) {
-		memset(ublock + sizeof(*block), 0, size - sizeof(*block));
+		memset(((uint8_t *) ublock) + sizeof(*block), 0,
+		       size - sizeof(*block));
 
 		size = sizeof(*block);
 	}
