@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2014-2020, Intel Corporation
+ * Copyright (c) 2014-2023, Intel Corporation
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -223,7 +224,8 @@ static inline int pkt_to_user(struct pt_packet *upkt, size_t size,
 
 	/* Zero out any unknown bytes. */
 	if (sizeof(*pkt) < size) {
-		memset(upkt + sizeof(*pkt), 0, size - sizeof(*pkt));
+		memset(((uint8_t *) upkt) + sizeof(*pkt), 0,
+		       size - sizeof(*pkt));
 
 		size = sizeof(*pkt);
 	}
@@ -543,8 +545,23 @@ int pt_pkt_decode_tma(struct pt_packet_decoder *decoder,
 
 	size = pt_pkt_read_tma(&packet->payload.tma, decoder->pos,
 			       &decoder->config);
-	if (size < 0)
+	if (size < 0) {
+		/** SKZ84: Use of VMX TSC Scaling or TSC Offsetting Will Result
+		 *         in Corrupted Intel PT Packets
+		 *
+		 * We cannot detect all kinds of corruption but we can detect
+		 * reserved bits being set.
+		 */
+		if (decoder->config.errata.skz84
+		    && (size == -pte_bad_packet)) {
+			size = ptps_tma + 1;
+
+			packet->type = ppt_invalid;
+			packet->size = (uint8_t) size;
+		}
+
 		return size;
+	}
 
 	packet->type = ppt_tma;
 	packet->size = (uint8_t) size;
