@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2014-2022, Intel Corporation
+ * Copyright (c) 2014-2023, Intel Corporation
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -43,6 +44,15 @@ int pev_time_to_tsc(uint64_t *tsc, uint64_t time,
 	if (!tsc || !config)
 		return -pte_internal;
 
+	/* "time 0" is for synthesized events, and is not a real time. Using
+	 * the normal conversion for a synthesized time causes problems, so
+	 * just translate it as TSC time 0 ("beginning of time").
+	 */
+	if (!time) {
+		*tsc = 0;
+		return 0;
+	}
+
 	if (!pev_config_has(config, time_zero))
 		return -pte_bad_config;
 
@@ -197,6 +207,9 @@ int pev_read(struct pev_event *event, const uint8_t *begin, const uint8_t *end,
 	header = (const struct perf_event_header *) pos;
 	pos += sizeof(*header);
 
+	if (header->size < sizeof(*header))
+		return -pte_nosync;
+
 	if (!header->type || (end < (begin + header->size)))
 		return -pte_eos;
 
