@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2014-2022, Intel Corporation
+ * Copyright (c) 2014-2023, Intel Corporation
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -281,13 +282,13 @@ static struct ptunit_result time_to_tsc_bad_config(void)
 	memset(&config, 0, sizeof(config));
 	config.time_mult = 1;
 
-	errcode = pev_time_to_tsc(&tsc, 0x0ull, &config);
+	errcode = pev_time_to_tsc(&tsc, 0x1ull, &config);
 	ptu_int_eq(errcode, -pte_bad_config);
 
 	config.size = sizeof(config);
 	config.time_mult = 0;
 
-	errcode = pev_time_to_tsc(&tsc, 0x0ull, &config);
+	errcode = pev_time_to_tsc(&tsc, 0x1ull, &config);
 	ptu_int_eq(errcode, -pte_bad_config);
 
 	return ptu_passed();
@@ -363,6 +364,30 @@ static struct ptunit_result write_bad_config(void)
 	return ptu_passed();
 }
 
+static struct ptunit_result nosync(uint16_t type)
+{
+	union {
+		struct perf_event_header header;
+		uint8_t buffer[128];
+	} input;
+	struct pev_config config;
+	struct pev_event event;
+	int errcode;
+
+	pev_config_init(&config);
+
+	memset(input.buffer, 0xcc, sizeof(input.buffer));
+	input.header.type = type;
+	input.header.misc = 0;
+	input.header.size = sizeof(input.header.type);
+
+	errcode = pev_read(&event, input.buffer,
+			   input.buffer + sizeof(input.buffer), &config);
+	ptu_int_eq(errcode, -pte_nosync);
+
+	return ptu_passed();
+}
+
 static struct ptunit_result bad_string(uint16_t type)
 {
 	union {
@@ -751,6 +776,10 @@ int main(int argc, char **argv)
 	ptu_run_p(suite, bad_string, PERF_RECORD_COMM);
 	ptu_run_p(suite, bad_string, PERF_RECORD_MMAP2);
 
+	ptu_run_p(suite, nosync, PERF_RECORD_MMAP);
+	ptu_run_p(suite, nosync, PERF_RECORD_COMM);
+	ptu_run_p(suite, nosync, 0);
+
 	ptu_run_f(suite, mmap, pfix);
 	ptu_run_f(suite, lost, pfix);
 	ptu_run_f(suite, comm, pfix);
