@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2013-2020, Intel Corporation
+ * Copyright (c) 2013-2023, Intel Corporation
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -126,7 +127,7 @@ static void sb_rename_file(struct sb_file *sb)
 	}
 
 	/* Print the name of the sideband file for test.bash. */
-	printf("%s\n", filename);
+	printf("%s ", filename);
 }
 
 #endif /* defined(FEATURE_SIDEBAND) */
@@ -354,7 +355,7 @@ static int p_gen_expfile(struct parser *p)
 
 		if (errcode == 0 && strcmp(pd->name, ".exp") == 0) {
 			fclose(f);
-			printf("%s\n", filename);
+			printf("%s ", filename);
 			free(filename);
 			filename = expfilename(p, pd->payload);
 			if (!filename)
@@ -546,11 +547,10 @@ error:
 
 	fclose(f);
 	if (errcode < 0 && errcode != -err_out_of_range) {
-		fprintf(stderr, "fatal: %s could not be created:\n", filename);
+		fprintf(stderr, "fatal: error generating %s:\n", filename);
 		yasm_print_err(p->y, "", errcode);
-		remove(filename);
 	} else
-		printf("%s\n", filename);
+		printf("%s ", filename);
 	free(filename);
 
 	/* If there are no lines left, we are done.  */
