@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2013-2020, Intel Corporation
+ * Copyright (c) 2013-2023, Intel Corporation
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -286,8 +287,8 @@ static void help(const char *name)
 	printf("  --nom-freq <n>                       set the nominal frequency (MSR_PLATFORM_INFO[15:8]) to <n>.\n");
 	printf("  --cpuid-0x15.eax                     set the value of cpuid[0x15].eax.\n");
 	printf("  --cpuid-0x15.ebx                     set the value of cpuid[0x15].ebx.\n");
-	printf("  --insn-decoder                       use the instruction flow decoder (default).\n");
-	printf("  --block-decoder                      use the block decoder.\n");
+	printf("  --insn-decoder                       use the instruction flow decoder.\n");
+	printf("  --block-decoder                      use the block decoder (default).\n");
 	printf("  --block:show-blocks                  show blocks in the output.\n");
 	printf("  --block:end-on-call                  set the end-on-call block decoder flag.\n");
 	printf("  --block:end-on-jump                  set the end-on-jump block decoder flag.\n");
@@ -739,6 +740,7 @@ static void check_insn_iclass(const xed_inst_t *inst,
 		case XED_ICLASS_IRETD:
 		case XED_ICLASS_IRETQ:
 		case XED_ICLASS_SYSRET:
+		case XED_ICLASS_SYSRET64:
 		case XED_ICLASS_SYSRET_AMD:
 		case XED_ICLASS_SYSEXIT:
 		case XED_ICLASS_VMLAUNCH:
